package oracle.forms.fd;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import javax.swing.JOptionPane;
import oracle.forms.handler.IHandler;
import oracle.forms.ui.*;
import oracle.forms.properties.ID;

  /**
   * A simple bean to read/write client machine's file
   *
   * @author Francois Degrelle
   * @version 1.3
   */

public class ClientFile extends VBean
{
  private   IHandler      m_handler;  
  private   String        sFileName = "" ;
  private   String        sCurValue = "" ;
  private   boolean       bLog = false ;
  private   String        sFileText = "" ;
  protected static final ID pSetFile    = ID.registerProperty("SET_FILE_NAME");      
  protected static final ID pReadFile   = ID.registerProperty("READ_FROM_FILE");      
  protected static final ID pGetText    = ID.registerProperty("GET_TEXT");        
  protected static final ID pWriteFile  = ID.registerProperty("WRITE_TO_FILE");        
  protected static final ID pAppendFile = ID.registerProperty("APPEND_TO_FILE");        
  
  /**
   * Constructor 
   */
  public ClientFile()
  {
    super();
  } 

  public void setFileName( String p_filename )
  {
       sFileName = p_filename ;
       log( "Filename : " + p_filename ) ;
  }
  
  public void writeToFile( String p_text )
  {
       sCurValue = p_text ;
       writeFile( 1, false ) ;
  }  

  public void writeAppendToFile( String p_text )
  {
       sCurValue = p_text ;
       writeFile( 1, true ) ;
  }  
  
  public String readFromFile()
  {
       boolean bStatus = false ;
       bStatus = readFile() ;
       if( bStatus ) return sCurValue ;
       else return "" ;
  }    
  
  public boolean setProperty(ID _ID, Object _args)
  {
    // read the file
    if (_ID==pReadFile)
    {  
      if(sFileName != null) sFileText = readFromFile() ;
    }
    
    // Write the file
    else if (_ID==pWriteFile)
    {  
      if(sFileName != null) writeToFile((String)_args) ;
    }    
    
    // Write append the file
    else if (_ID==pAppendFile)
    {  
      if(sFileName != null) writeAppendToFile((String)_args) ;
    }        
    
    // set the file name
    else if (_ID==pSetFile)
    {  
      System.out.println("SetFile="+(String)_args);
      sFileName = (String)_args ;
    }        
    
     else{
        return super.setProperty(_ID, _args);
     }
     return true ;
  }
  
  public Object getProperty(ID property)
    {
      if (property == pGetText)
      {
        // return the SQL result
        return "" + sFileText ;
      }
      else // default behaviour
      {
        return super.getProperty(property);
      }
    }  
  
  public void setLog()
  {
       bLog = true ;
       log("log enabled") ;
  }  
  
  /****************************
   *  Write a text to a file  *
   ***************************/
  private void writeFile( int iAction, boolean bAppend )
  {
      PrintWriter fileOut=null;
      String line="" ;

      // open the file
      log("writeFile : try to open : " + sFileName ) ;
      try
      {
        fileOut = new PrintWriter(new FileWriter(sFileName,bAppend));
      } catch (Exception e)
      {
        log("writeFile opening error:"+e); 
      }
      // write to the file
      if( iAction == 1)
      {
        try
        {
          log("writeFile : try to write to : "+ sFileName ) ;
          fileOut.println( sCurValue ) ;
        } catch (Exception e)
        {
          log("writeFile writing error:"+e); 
        }
      }
     // close the file
     try
     {
       fileOut.close();
     } catch (Exception e)
     {
       log("writeFile closing error:"+e);
     } 
    //JOptionPane.showMessageDialog(this, "File : "+sFileName+" created", "Write", JOptionPane.PLAIN_MESSAGE);
  }

  /*****************************
   *  read a text from a file  *
   ****************************/
  private boolean readFile()
   {
     BufferedReader fileIn=null;
     String line = "" ;
     sCurValue = "" ;
    
     // Open the file
     log("readFile : try to open : " + sFileName ) ;
     try
     {
       fileIn = new BufferedReader( new FileReader(sFileName));
     } catch (FileNotFoundException e)
     {
       log("readFile open error : "+sFileName+" not found ");
       //JOptionPane.showMessageDialog(this, "File : "+sFileName+" not found", "Read", JOptionPane.PLAIN_MESSAGE);
       return false ;
     }
       catch (IOException e)
     {
       log("readFile open error : "+e);
       return false;
     }     
     // read the file
     log("readFile : try to read from : " + sFileName ) ;
     try
     {
       while((line=fileIn.readLine())!= null)
       {
           sCurValue += line + '\n';
       }
     }catch (Exception e)
     {
       log("readFile reading error:"+e);
       return false ;
     }
     try
     {
       fileIn.close();
     } catch (Exception e)
     {
       log("readFile closing error:"+e);
       return false ;
     }
     return true ;
   }

  /*******************************
   *  Ouput messages on console  *
   ******************************/
  private void log( String msg)
  {
     if( bLog ) System.out.println(msg) ;
  }
  
} // ClientFile
